==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/hybridnetwork/kotlin/inputs/DependsOnProfileArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.hybridnetwork.kotlin.inputs

import com.pulumi.azurenative.hybridnetwork.inputs.DependsOnProfileArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Depends on profile definition.
 * @property installDependsOn Application installation operation dependency.
 * @property uninstallDependsOn Application deletion operation dependency.
 * @property updateDependsOn Application update operation dependency.
 */
public data class DependsOnProfileArgs(
    public val installDependsOn: Output<List<String>>? = null,
    public val uninstallDependsOn: Output<List<String>>? = null,
    public val updateDependsOn: Output<List<String>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.hybridnetwork.inputs.DependsOnProfileArgs> {
    override fun toJava(): com.pulumi.azurenative.hybridnetwork.inputs.DependsOnProfileArgs =
        com.pulumi.azurenative.hybridnetwork.inputs.DependsOnProfileArgs.builder()
            .installDependsOn(installDependsOn?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .uninstallDependsOn(uninstallDependsOn?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .updateDependsOn(updateDependsOn?.applyValue({ args0 -> args0.map({ args0 -> args0 }) })).build()
}

/**
 * Builder for [DependsOnProfileArgs].
 */
@PulumiTagMarker
public class DependsOnProfileArgsBuilder internal constructor() {
    private var installDependsOn: Output<List<String>>? = null

    private var uninstallDependsOn: Output<List<String>>? = null

    private var updateDependsOn: Output<List<String>>? = null

    /**
     * @param value Application installation operation dependency.
     */
    @JvmName("bxsfqtaqskelblwu")
    public suspend fun installDependsOn(`value`: Output<List<String>>) {
        this.installDependsOn = value
    }

    @JvmName("aqjqwsvdcpbjntat")
    public suspend fun installDependsOn(vararg values: Output<String>) {
        this.installDependsOn = Output.all(values.asList())
    }

    /**
     * @param values Application installation operation dependency.
     */
    @JvmName("fpuixeeyyycgqbqc")
    public suspend fun installDependsOn(values: List<Output<String>>) {
        this.installDependsOn = Output.all(values)
    }

    /**
     * @param value Application deletion operation dependency.
     */
    @JvmName("mboigseqfswdpnxe")
    public suspend fun uninstallDependsOn(`value`: Output<List<String>>) {
        this.uninstallDependsOn = value
    }

    @JvmName("dkdqahgxffcporij")
    public suspend fun uninstallDependsOn(vararg values: Output<String>) {
        this.uninstallDependsOn = Output.all(values.asList())
    }

    /**
     * @param values Application deletion operation dependency.
     */
    @JvmName("kdamyhitidqfapmd")
    public suspend fun uninstallDependsOn(values: List<Output<String>>) {
        this.uninstallDependsOn = Output.all(values)
    }

    /**
     * @param value Application update operation dependency.
     */
    @JvmName("udxfbmlufqnxeume")
    public suspend fun updateDependsOn(`value`: Output<List<String>>) {
        this.updateDependsOn = value
    }

    @JvmName("dmdhotbexpwgeyee")
    public suspend fun updateDependsOn(vararg values: Output<String>) {
        this.updateDependsOn = Output.all(values.asList())
    }

    /**
     * @param values Application update operation dependency.
     */
    @JvmName("avtgjysopghwolfc")
    public suspend fun updateDependsOn(values: List<Output<String>>) {
        this.updateDependsOn = Output.all(values)
    }

    /**
     * @param value Application installation operation dependency.
     */
    @JvmName("nucaxixympdrvwjg")
    public suspend fun installDependsOn(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.installDependsOn = mapped
    }

    /**
     * @param values Application installation operation dependency.
     */
    @JvmName("xisnlpnpuymsjoxw")
    public suspend fun installDependsOn(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.installDependsOn = mapped
    }

    /**
     * @param value Application deletion operation dependency.
     */
    @JvmName("qchpsyvhsjmtkkga")
    public suspend fun uninstallDependsOn(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.uninstallDependsOn = mapped
    }

    /**
     * @param values Application deletion operation dependency.
     */
    @JvmName("vgquhjksomgqgipv")
    public suspend fun uninstallDependsOn(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.uninstallDependsOn = mapped
    }

    /**
     * @param value Application update operation dependency.
     */
    @JvmName("padvulbjhbsaagnl")
    public suspend fun updateDependsOn(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.updateDependsOn = mapped
    }

    /**
     * @param values Application update operation dependency.
     */
    @JvmName("uyodtgwwtqavbspu")
    public suspend fun updateDependsOn(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.updateDependsOn = mapped
    }

    internal fun build(): DependsOnProfileArgs = DependsOnProfileArgs(
        installDependsOn = installDependsOn,
        uninstallDependsOn = uninstallDependsOn,
        updateDependsOn = updateDependsOn,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/hybridnetwork/kotlin/inputs/DependsOnProfileArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.hybridnetwork.kotlin.inputs

import com.pulumi.azurenative.hybridnetwork.inputs.DependsOnProfileArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Depends on profile definition.
 * @property installDependsOn Application installation operation dependency.
 * @property uninstallDependsOn Application deletion operation dependency.
 * @property updateDependsOn Application update operation dependency.
 */
public data class DependsOnProfileArgs(
    public val installDependsOn: Output<List<String>>? = null,
    public val uninstallDependsOn: Output<List<String>>? = null,
    public val updateDependsOn: Output<List<String>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.hybridnetwork.inputs.DependsOnProfileArgs> {
    override fun toJava(): com.pulumi.azurenative.hybridnetwork.inputs.DependsOnProfileArgs =
        com.pulumi.azurenative.hybridnetwork.inputs.DependsOnProfileArgs.builder()
            .installDependsOn(installDependsOn?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .uninstallDependsOn(uninstallDependsOn?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .updateDependsOn(updateDependsOn?.applyValue({ args0 -> args0.map({ args0 -> args0 }) })).build()
}

/**
 * Builder for [DependsOnProfileArgs].
 */
@PulumiTagMarker
public class DependsOnProfileArgsBuilder internal constructor() {
    private var installDependsOn: Output<List<String>>? = null

    private var uninstallDependsOn: Output<List<String>>? = null

    private var updateDependsOn: Output<List<String>>? = null

    /**
     * @param value Application installation operation dependency.
     */
    @JvmName("dikkrkbvclfbaghx")
    public suspend fun installDependsOn(`value`: Output<List<String>>) {
        this.installDependsOn = value
    }

    @JvmName("rvmoaotqkrjgeawp")
    public suspend fun installDependsOn(vararg values: Output<String>) {
        this.installDependsOn = Output.all(values.asList())
    }

    /**
     * @param values Application installation operation dependency.
     */
    @JvmName("kfebfrosdqsqyuyk")
    public suspend fun installDependsOn(values: List<Output<String>>) {
        this.installDependsOn = Output.all(values)
    }

    /**
     * @param value Application deletion operation dependency.
     */
    @JvmName("mnljjtwbjkshdxvd")
    public suspend fun uninstallDependsOn(`value`: Output<List<String>>) {
        this.uninstallDependsOn = value
    }

    @JvmName("smcfmcwufqdaqcva")
    public suspend fun uninstallDependsOn(vararg values: Output<String>) {
        this.uninstallDependsOn = Output.all(values.asList())
    }

    /**
     * @param values Application deletion operation dependency.
     */
    @JvmName("aflsfhxuhygljkwu")
    public suspend fun uninstallDependsOn(values: List<Output<String>>) {
        this.uninstallDependsOn = Output.all(values)
    }

    /**
     * @param value Application update operation dependency.
     */
    @JvmName("bmlnxqxsfcepqcip")
    public suspend fun updateDependsOn(`value`: Output<List<String>>) {
        this.updateDependsOn = value
    }

    @JvmName("rflbsouicryimqxw")
    public suspend fun updateDependsOn(vararg values: Output<String>) {
        this.updateDependsOn = Output.all(values.asList())
    }

    /**
     * @param values Application update operation dependency.
     */
    @JvmName("ehhkyewgcsuilmmh")
    public suspend fun updateDependsOn(values: List<Output<String>>) {
        this.updateDependsOn = Output.all(values)
    }

    /**
     * @param value Application installation operation dependency.
     */
    @JvmName("dmkharunegmlmkxl")
    public suspend fun installDependsOn(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.installDependsOn = mapped
    }

    /**
     * @param values Application installation operation dependency.
     */
    @JvmName("ulyvkersyjtvlrly")
    public suspend fun installDependsOn(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.installDependsOn = mapped
    }

    /**
     * @param value Application deletion operation dependency.
     */
    @JvmName("vlcbsicngxofxyck")
    public suspend fun uninstallDependsOn(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.uninstallDependsOn = mapped
    }

    /**
     * @param values Application deletion operation dependency.
     */
    @JvmName("xpjvucareimmnpuv")
    public suspend fun uninstallDependsOn(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.uninstallDependsOn = mapped
    }

    /**
     * @param value Application update operation dependency.
     */
    @JvmName("woplateexdcdvbhl")
    public suspend fun updateDependsOn(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.updateDependsOn = mapped
    }

    /**
     * @param values Application update operation dependency.
     */
    @JvmName("dqsdnsbyoorpxjjj")
    public suspend fun updateDependsOn(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.updateDependsOn = mapped
    }

    internal fun build(): DependsOnProfileArgs = DependsOnProfileArgs(
        installDependsOn = installDependsOn,
        uninstallDependsOn = uninstallDependsOn,
        updateDependsOn = updateDependsOn,
    )
}
